@@ -28,22 +28,17 @@ CONFIG = config[ENVIRONMENT]['api']
 
 
 class Client(object):
-    def __init__(self, api_key: str = None, user_id: str = None, access_key: str = None, secret_key: str = None, version: int = None,
+    def __init__(self, secret_token: str = None, version: int = None,
                  host: str = CONFIG['url']):
         logger.info("Instantiate API class")
 
         self._version = version or DEFAULT_API_VERSION
         self.session = requests.Session()
-        self.api_key = api_key
-        self.access_key = access_key
-        self.secret_key = secret_key
+        self.secret_token = secret_token
         self.domain_url = host
-        self.user_id = user_id
 
-        self.token = None
-
-        if not self.api_key and not (self.access_key and self.secret_key):
-            raise InscribeAPIException("You must include an access_key and secret_key")
+        if not self.secret_token:
+            raise InscribeAPIException("You must include a secret token. Downgrade to v2.6.0 if you wish to use older forms of Inscribe API keys.")
 
     def create_customer(self, name: str) -> dict:
         """
@@ -241,25 +236,22 @@ class Client(object):
         url = f"/webhooks/{webhook_id}/"
         return self._delete(url)
 
-    def update_webhook(self, webhook_id : str, webhook_url : str) -> dict:
+    def update_webhook(self, webhook_id : str, webhook_url : str, webhook_type : str) -> dict:
         """
         Update webhook.
 
         :param webhook_id: id of the webhook to update.
         :param webhook_url: the URL that will receive document_processed events.
+        :param webhook_type: the type of the webhook
 
         """
         url = f"/webhooks/{webhook_id}/"
-        payload = dict(url=webhook_url)
+        payload = dict(url=webhook_url, type=webhook_type)
         return self._put(url, payload=payload)
 
     @property
     def headers(self):
-        if self.access_key and self.secret_key:
-            encoded_keys = base64.b64encode(f"{self.access_key}:{self.secret_key}".encode("utf-8")).decode("ascii")
-            return {'Authorization': f"Inscribe {encoded_keys}"}
-
-        return {'Authorization': self.api_key}
+        return {'Authorization': f"Inscribe {self.secret_token}"}
 
     @property
     def version(self):
